Emperor

Emperor is an interactive next generation tool for the analysis, visualization and understanding of high throughput microbial ecology datasets.

Due to its tailor-made graphical user interface, delving into a new dataset to elucidate the patterns hidden in the data, has never been easier. Emperor brings a rich set of customizations and modifications that can be integrated into any QIIME or scikit-bio compliant dataset; with lightweight data files and hardware accelerated graphics, constitutes itself as the state of the art for analyzing N-dimensional data using principal coordinates analysis.

If you use Emperor for any published research, please include the following citation:

> EMPeror: a tool for visualizing high-throughput microbial community data
> Vazquez-Baeza Y, Pirrung M, Gonzalez A, Knight R.
> Gigascience. 2013 Nov 26;2(1):16.
> link to paper

If you use Emperor's animations feature for a publication, please include the following citation:

> Bringing the Dynamic Microbiome to Life with Animations
> Vazquez-Baeza Y, Gonzalez A, Smarr L, McDonald D, Morton J, Navas-Molina J, Knight R.
> Cell Host & Microbe. 2017 January 11;21(1).
> link to paper

Important! We are rewritting Emperor with a new architecture, if you are interested in this unstable version, please click here.